@@ -3,7 +3,7 @@
 import base64
 import contextlib
 import datetime
-from typing import Any, Dict, List, Optional, Tuple, cast
+from typing import Any, Optional, cast
 
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
@@ -31,9 +31,9 @@ class CertificateAuthority(BaseModel):
         self,
         region: str,
         account_id: str,
-        certificate_authority_configuration: Dict[str, Any],
+        certificate_authority_configuration: dict[str, Any],
         certificate_authority_type: str,
-        revocation_configuration: Dict[str, Any],
+        revocation_configuration: dict[str, Any],
         security_standard: Optional[str],
     ):
         self.id = mock_random.uuid4()
@@ -42,7 +42,7 @@ class CertificateAuthority(BaseModel):
         self.region_name = region
         self.certificate_authority_configuration = certificate_authority_configuration
         self.certificate_authority_type = certificate_authority_type
-        self.revocation_configuration: Dict[str, Any] = {
+        self.revocation_configuration: dict[str, Any] = {
             "CrlConfiguration": {"Enabled": False}
         }
         self.set_revocation_configuration(revocation_configuration)
@@ -64,7 +64,7 @@ class CertificateAuthority(BaseModel):
 
         self.certificate_bytes: bytes = b""
         self.certificate_chain: Optional[bytes] = None
-        self.issued_certificates: Dict[str, bytes] = dict()
+        self.issued_certificates: dict[str, bytes] = {}
 
         self.subject = self.certificate_authority_configuration.get("Subject", {})
 
@@ -72,7 +72,7 @@ class CertificateAuthority(BaseModel):
         self,
         subject: x509.Name,
         public_key: rsa.RSAPublicKey,
-        extensions: List[Tuple[x509.ExtensionType, bool]],
+        extensions: list[tuple[x509.ExtensionType, bool]],
     ) -> bytes:
         builder = (
             x509.CertificateBuilder()
@@ -166,7 +166,7 @@ class CertificateAuthority(BaseModel):
 
     def _x509_extensions(
         self, csr: x509.CertificateSigningRequest, template_arn: Optional[str]
-    ) -> List[Tuple[x509.ExtensionType, bool]]:
+    ) -> list[tuple[x509.ExtensionType, bool]]:
         """
         Uses a PCA certificate template ARN to return a list of X.509 extensions.
         These extensions are part of the constructed certificate.
@@ -267,7 +267,7 @@ class CertificateAuthority(BaseModel):
         return self.issued_certificates[certificate_arn]
 
     def set_revocation_configuration(
-        self, revocation_configuration: Optional[Dict[str, Any]]
+        self, revocation_configuration: Optional[dict[str, Any]]
     ) -> None:
         if revocation_configuration is not None:
             self.revocation_configuration = revocation_configuration
@@ -314,7 +314,7 @@ class CertificateAuthority(BaseModel):
         self.status = "ACTIVE"
         self.updated_at = unix_time()
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         dct = {
             "Arn": self.arn,
             "OwnerAccount": self.account_id,
@@ -352,16 +352,16 @@ class ACMPCABackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.certificate_authorities: Dict[str, CertificateAuthority] = dict()
+        self.certificate_authorities: dict[str, CertificateAuthority] = {}
         self.tagger = TaggingService()
 
     def create_certificate_authority(
         self,
-        certificate_authority_configuration: Dict[str, Any],
-        revocation_configuration: Dict[str, Any],
+        certificate_authority_configuration: dict[str, Any],
+        revocation_configuration: dict[str, Any],
         certificate_authority_type: str,
         security_standard: Optional[str],
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
     ) -> str:
         """
         The following parameters are not yet implemented: IdempotencyToken, KeyStorageSecurityStandard, UsageMode
@@ -388,7 +388,7 @@ class ACMPCABackend(BaseBackend):
 
     def get_certificate_authority_certificate(
         self, certificate_authority_arn: str
-    ) -> Tuple[bytes, Optional[bytes]]:
+    ) -> tuple[bytes, Optional[bytes]]:
         ca = self.describe_certificate_authority(certificate_authority_arn)
         if ca.status != "ACTIVE":
             raise InvalidStateException(certificate_authority_arn)
@@ -400,7 +400,7 @@ class ACMPCABackend(BaseBackend):
 
     def list_tags(
         self, certificate_authority_arn: str
-    ) -> Dict[str, List[Dict[str, str]]]:
+    ) -> dict[str, list[dict[str, str]]]:
         """
         Pagination is not yet implemented
         """
@@ -409,7 +409,7 @@ class ACMPCABackend(BaseBackend):
     def update_certificate_authority(
         self,
         certificate_authority_arn: str,
-        revocation_configuration: Dict[str, Any],
+        revocation_configuration: dict[str, Any],
         status: str,
     ) -> None:
         ca = self.describe_certificate_authority(certificate_authority_arn)
@@ -435,7 +435,7 @@ class ACMPCABackend(BaseBackend):
 
     def get_certificate(
         self, certificate_authority_arn: str, certificate_arn: str
-    ) -> Tuple[bytes, Optional[str]]:
+    ) -> tuple[bytes, Optional[str]]:
         """
         The CertificateChain will always return None for now
         """
@@ -464,12 +464,12 @@ class ACMPCABackend(BaseBackend):
         """
 
     def tag_certificate_authority(
-        self, certificate_authority_arn: str, tags: List[Dict[str, str]]
+        self, certificate_authority_arn: str, tags: list[dict[str, str]]
     ) -> None:
         self.tagger.tag_resource(certificate_authority_arn, tags)
 
     def untag_certificate_authority(
-        self, certificate_authority_arn: str, tags: List[Dict[str, str]]
+        self, certificate_authority_arn: str, tags: list[dict[str, str]]
     ) -> None:
         self.tagger.untag_resource_using_tags(certificate_authority_arn, tags)
 
@@ -502,7 +502,7 @@ class ACMPCABackend(BaseBackend):
     def list_certificate_authorities(
         self,
         resource_owner: Optional[str] = None,
-    ) -> List[CertificateAuthority]:
+    ) -> list[CertificateAuthority]:
         """
         Lists the private certificate authorities that you created by using the CreateCertificateAuthority action.
         """
