@@ -1,7 +1,7 @@
 """DirectoryServiceBackend class with methods for supported APIs."""
 
 import copy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
@@ -31,7 +31,7 @@ class LdapsSettingInfo(BaseModel):
         self.ldaps_status = "Enabled"
         self.ldaps_status_reason = ""
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "LastUpdatedDateTime": self.last_updated_date_time,
             "LDAPSStatus": self.ldaps_status,
@@ -45,7 +45,7 @@ class LogSubscription(BaseModel):
         self.log_group_name = log_group_name
         self.created_date_time = unix_time()
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "SubscriptionCreatedDateTime": self.created_date_time,
             "DirectoryId": self.directory_id,
@@ -61,7 +61,7 @@ class Trust(BaseModel):
         trust_password: str,
         trust_direction: str,
         trust_type: Optional[str],
-        conditional_forwarder_ip_addrs: Optional[List[str]],
+        conditional_forwarder_ip_addrs: Optional[list[str]],
         selective_auth: Optional[str],
     ) -> None:
         self.trust_id = f"t-{mock_random.get_random_hex(10)}"
@@ -78,7 +78,7 @@ class Trust(BaseModel):
         self.conditional_forwarder_ip_addrs = conditional_forwarder_ip_addrs
         self.selective_auth = selective_auth
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "CreatedDateTime": self.created_date_time,
             "DirectoryId": self.directory_id,
@@ -94,7 +94,7 @@ class Trust(BaseModel):
         }
 
 
-class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
+class Directory(BaseModel):
     """Representation of a Simple AD Directory.
 
     When the "create" API for a Simple AD or a Microsoft AD directory is
@@ -126,12 +126,12 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
         password: str,
         directory_type: str,
         size: Optional[str] = None,
-        vpc_settings: Optional[Dict[str, Any]] = None,
-        connect_settings: Optional[Dict[str, Any]] = None,
+        vpc_settings: Optional[dict[str, Any]] = None,
+        connect_settings: Optional[dict[str, Any]] = None,
         short_name: Optional[str] = None,
         description: Optional[str] = None,
         edition: Optional[str] = None,
-    ):  # pylint: disable=too-many-arguments
+    ):
         self.account_id = account_id
         self.region = region
         self.name = name
@@ -153,8 +153,8 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
         self.stage = "Active"
         self.launch_time = unix_time()
         self.stage_last_updated_date_time = unix_time()
-        self.ldaps_settings_info: List[LdapsSettingInfo] = []
-        self.trusts: List[Trust] = []
+        self.ldaps_settings_info: list[LdapsSettingInfo] = []
+        self.trusts: list[Trust] = []
         self.settings = (
             copy.deepcopy(SETTINGS_ENTRIES_MODEL)
             if self.directory_type == "MicrosoftAD"
@@ -205,8 +205,8 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
         )
 
     def create_eni(
-        self, security_group_id: str, subnet_ids: List[str]
-    ) -> Tuple[List[str], List[str]]:
+        self, security_group_id: str, subnet_ids: list[str]
+    ) -> tuple[list[str], list[str]]:
         """Return ENI ids and primary addresses created for each subnet."""
         eni_ids = []
         subnet_ips = []
@@ -253,7 +253,7 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
             for setting in self.ldaps_settings_info:
                 setting.ldaps_status = "Disabled"
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Create a dictionary of attributes for Directory."""
         attributes = {
             "AccessUrl": self.access_url,
@@ -291,11 +291,11 @@ class DirectoryServiceBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.directories: Dict[str, Directory] = {}
-        self.log_subscriptions: Dict[str, LogSubscription] = {}
+        self.directories: dict[str, Directory] = {}
+        self.log_subscriptions: dict[str, LogSubscription] = {}
         self.tagger = TaggingService()
 
-    def _verify_subnets(self, region: str, vpc_settings: Dict[str, Any]) -> None:
+    def _verify_subnets(self, region: str, vpc_settings: dict[str, Any]) -> None:
         """Verify subnets are valid, else raise an exception.
 
         If settings are valid, add AvailabilityZones to vpc_settings.
@@ -338,9 +338,9 @@ class DirectoryServiceBackend(BaseBackend):
         password: str,
         description: str,
         size: str,
-        connect_settings: Dict[str, Any],
-        tags: List[Dict[str, str]],
-    ) -> str:  # pylint: disable=too-many-arguments
+        connect_settings: dict[str, Any],
+        tags: list[dict[str, str]],
+    ) -> str:
         """Create a fake AD Connector."""
         if len(self.directories) > Directory.CONNECTED_DIRECTORIES_LIMIT:
             raise DirectoryLimitExceededException(
@@ -398,9 +398,9 @@ class DirectoryServiceBackend(BaseBackend):
         password: str,
         description: str,
         size: str,
-        vpc_settings: Dict[str, Any],
-        tags: List[Dict[str, str]],
-    ) -> str:  # pylint: disable=too-many-arguments
+        vpc_settings: dict[str, Any],
+        tags: list[dict[str, str]],
+    ) -> str:
         """Create a fake Simple Ad Directory."""
         if len(self.directories) > Directory.CLOUDONLY_DIRECTORIES_LIMIT:
             raise DirectoryLimitExceededException(
@@ -453,7 +453,7 @@ class DirectoryServiceBackend(BaseBackend):
                 f"Directory {directory_id} does not exist"
             )
 
-    def create_alias(self, directory_id: str, alias: str) -> Dict[str, str]:
+    def create_alias(self, directory_id: str, alias: str) -> dict[str, str]:
         """Create and assign an alias to a directory."""
         self._validate_directory_id(directory_id)
 
@@ -481,10 +481,10 @@ class DirectoryServiceBackend(BaseBackend):
         short_name: str,
         password: str,
         description: str,
-        vpc_settings: Dict[str, Any],
+        vpc_settings: dict[str, Any],
         edition: str,
-        tags: List[Dict[str, str]],
-    ) -> str:  # pylint: disable=too-many-arguments
+        tags: list[dict[str, str]],
+    ) -> str:
         """Create a fake Microsoft Ad Directory."""
         if len(self.directories) > Directory.CLOUDONLY_MICROSOFT_AD_LIMIT:
             raise DirectoryLimitExceededException(
@@ -568,8 +568,8 @@ class DirectoryServiceBackend(BaseBackend):
 
     @paginate(pagination_model=PAGINATION_MODEL)
     def describe_directories(
-        self, directory_ids: Optional[List[str]] = None
-    ) -> List[Directory]:
+        self, directory_ids: Optional[list[str]] = None
+    ) -> list[Directory]:
         """Return info on all directories or directories with matching IDs."""
         for directory_id in directory_ids or self.directories:
             self._validate_directory_id(directory_id)
@@ -579,7 +579,7 @@ class DirectoryServiceBackend(BaseBackend):
             directories = [x for x in directories if x.directory_id in directory_ids]
         return sorted(directories, key=lambda x: x.launch_time)
 
-    def get_directory_limits(self) -> Dict[str, Any]:
+    def get_directory_limits(self) -> dict[str, Any]:
         """Return hard-coded limits for the directories."""
         counts = {"SimpleAD": 0, "MicrosoftAD": 0, "ConnectedAD": 0}
         for directory in self.directories.values():
@@ -606,7 +606,7 @@ class DirectoryServiceBackend(BaseBackend):
         }
 
     def add_tags_to_resource(
-        self, resource_id: str, tags: List[Dict[str, str]]
+        self, resource_id: str, tags: list[dict[str, str]]
     ) -> None:
         """Add or overwrite one or more tags for specified directory."""
         self._validate_directory_id(resource_id)
@@ -617,13 +617,13 @@ class DirectoryServiceBackend(BaseBackend):
             raise TagLimitExceededException("Tag limit exceeded")
         self.tagger.tag_resource(resource_id, tags)
 
-    def remove_tags_from_resource(self, resource_id: str, tag_keys: List[str]) -> None:
+    def remove_tags_from_resource(self, resource_id: str, tag_keys: list[str]) -> None:
         """Removes tags from a directory."""
         self._validate_directory_id(resource_id)
         self.tagger.untag_resource_using_names(resource_id, tag_keys)
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_tags_for_resource(self, resource_id: str) -> List[Dict[str, str]]:
+    def list_tags_for_resource(self, resource_id: str) -> list[dict[str, str]]:
         """List all tags on a directory."""
         self._validate_directory_id(resource_id)
         return self.tagger.list_tags_for_resource(resource_id).get("Tags")  # type: ignore[return-value]
@@ -635,7 +635,7 @@ class DirectoryServiceBackend(BaseBackend):
         trust_password: str,
         trust_direction: str,
         trust_type: Optional[str],
-        conditional_forwarder_ip_addrs: Optional[List[str]],
+        conditional_forwarder_ip_addrs: Optional[list[str]],
         selective_auth: Optional[str],
     ) -> str:
         self._validate_directory_id(directory_id)
@@ -661,8 +661,8 @@ class DirectoryServiceBackend(BaseBackend):
 
     @paginate(pagination_model=PAGINATION_MODEL)
     def describe_trusts(
-        self, directory_id: Optional[str], trust_ids: Optional[List[str]]
-    ) -> List[Trust]:
+        self, directory_id: Optional[str], trust_ids: Optional[list[str]]
+    ) -> list[Trust]:
         if directory_id:
             self._validate_directory_id(directory_id)
             directory = self.directories[directory_id]
@@ -696,7 +696,7 @@ class DirectoryServiceBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def describe_ldaps_settings(
         self, directory_id: str, type: str
-    ) -> List[LdapsSettingInfo]:
+    ) -> list[LdapsSettingInfo]:
         """Describe LDAPS settings for a Directory"""
         self._validate_directory_id(directory_id)
         directory = self.directories[directory_id]
@@ -722,7 +722,7 @@ class DirectoryServiceBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def describe_settings(
         self, directory_id: str, status: Optional[str]
-    ) -> List[Dict[str, str]]:
+    ) -> list[dict[str, str]]:
         """Describe settings for a Directory"""
         self._validate_directory_id(directory_id)
         directory = self.directories[directory_id]
@@ -740,7 +740,7 @@ class DirectoryServiceBackend(BaseBackend):
             queried_settings = directory.settings
         return queried_settings
 
-    def update_settings(self, directory_id: str, settings: List[Dict[str, Any]]) -> str:
+    def update_settings(self, directory_id: str, settings: list[dict[str, Any]]) -> str:
         self._validate_directory_id(directory_id)
         directory = self.directories[directory_id]
         if directory.directory_type not in ("MicrosoftAD"):
@@ -768,7 +768,7 @@ class DirectoryServiceBackend(BaseBackend):
     def list_log_subscriptions(
         self,
         directory_id: str,
-    ) -> List[LogSubscription]:
+    ) -> list[LogSubscription]:
         if directory_id:
             self._validate_directory_id(directory_id)
             log_subscription = self.log_subscriptions.get(directory_id, None)
@@ -777,9 +777,7 @@ class DirectoryServiceBackend(BaseBackend):
             else:
                 log_subscriptions = []
         else:
-            log_subscriptions = [
-                log_subscription for log_subscription in self.log_subscriptions.values()
-            ]
+            log_subscriptions = list(self.log_subscriptions.values())
         return log_subscriptions
 
     def delete_log_subscription(self, directory_id: str) -> None:
