@@ -74,6 +74,7 @@ class ElasticBlockStore(EC2BaseResponse):
         kms_key_id = self._get_param("KmsKeyId")
         iops = self._get_param("Iops")
         throughput = self._get_param("Throughput")
+        multi_attach_enabled = self._get_param("MultiAttachEnabled")
 
         self.error_on_dryrun()
 
@@ -86,6 +87,7 @@ class ElasticBlockStore(EC2BaseResponse):
             volume_type=volume_type,
             iops=iops,
             throughput=throughput,
+            multi_attach_enabled=multi_attach_enabled,
         )
         volume.add_tags(volume_tags)
         template = self.response_template(CREATE_VOLUME_RESPONSE)
@@ -95,11 +97,19 @@ class ElasticBlockStore(EC2BaseResponse):
         volume_id = self._get_param("VolumeId")
         target_size = self._get_param("Size")
         target_volume_type = self._get_param("VolumeType")
+        target_iops = self._get_param("Iops")
+        target_throughput = self._get_param("Throughput")
+        target_multi_attach_enabled = self._get_param("MultiAttachEnabled")
 
         self.error_on_dryrun()
 
         volume = self.ec2_backend.modify_volume(
-            volume_id, target_size, target_volume_type
+            volume_id,
+            target_size,
+            target_volume_type,
+            target_iops,
+            target_throughput,
+            target_multi_attach_enabled,
         )
         template = self.response_template(MODIFY_VOLUME_RESPONSE)
         return template.render(volume=volume)
@@ -264,6 +274,9 @@ CREATE_VOLUME_RESPONSE = """<CreateVolumeResponse xmlns="http://ec2.amazonaws.co
   {% if volume.throughput %}
     <throughput>{{ volume.throughput }}</throughput>
   {% endif %}
+  {% if volume.multi_attach_enabled %}
+    <multiAttachEnabled>{{ volume.multi_attach_enabled }}</multiAttachEnabled>
+  {% endif %}
 </CreateVolumeResponse>"""
 
 DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
@@ -316,6 +329,9 @@ DESCRIBE_VOLUMES_RESPONSE = """<DescribeVolumesResponse xmlns="http://ec2.amazon
              {% if volume.throughput %}
                <throughput>{{ volume.throughput }}</throughput>
              {% endif %}
+             {% if volume.multi_attach_enabled %}
+               <multiAttachEnabled>{{ volume.multi_attach_enabled }}</multiAttachEnabled>
+             {% endif %}
           </item>
       {% endfor %}
    </volumeSet>
@@ -464,12 +480,38 @@ MODIFY_VOLUME_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
     <volumeModification>
         {% set volume_modification = volume.modifications[-1] %}
         <modificationState>modifying</modificationState>
+        {% if volume_modification.original_size %}
         <originalSize>{{ volume_modification.original_size }}</originalSize>
-        <originalVolumeType>{{ volume_modification.original_volume_type }}</originalVolumeType>
+        {% endif %}
+        {% if volume_modification.original_volume_type %}
+            <originalVolumeType>{{ volume_modification.original_volume_type }}</originalVolumeType>
+        {% endif %}
+        {% if volume_modification.original_iops %}
+            <originalIops>{{ volume_modification.original_iops }}</originalIops>
+        {% endif %}
+        {% if volume_modification.original_throughput %}
+            <originalThroughput>{{ volume_modification.original_throughput }}</originalThroughput>
+        {% endif %}
+        {% if volume_modification.original_multi_attach_enabled is not none %}
+            <originalMultiAttachEnabled>{{ volume_modification.original_multi_attach_enabled }}</originalMultiAttachEnabled>
+        {% endif %}
         <progress>0</progress>
         <startTime>{{ volume_modification.start_time }}</startTime>
-        <targetSize>{{ volume_modification.target_size }}</targetSize>
-        <targetVolumeType>{{ volume_modification.target_volume_type }}</targetVolumeType>
+        {% if volume_modification.target_size %}
+            <targetSize>{{ volume_modification.target_size }}</targetSize>
+        {% endif %}
+        {% if volume_modification.target_volume_type %}
+            <targetVolumeType>{{ volume_modification.target_volume_type }}</targetVolumeType>
+        {% endif %}
+        {% if volume_modification.target_iops %}
+            <targetIops>{{ volume_modification.target_iops }}</targetIops>
+        {% endif %}
+        {% if volume_modification.target_throughput %}
+            <targetThroughput>{{ volume_modification.target_throughput }}</targetThroughput>
+        {% endif %}
+        {% if volume_modification.target_multi_attach_enabled %}
+            <targetMultiAttachEnabled>{{ volume_modification.target_multi_attach_enabled }}</targetMultiAttachEnabled>
+        {% endif %}
         <volumeId>{{ volume.id }}</volumeId>
     </volumeModification>
 </ModifyVolumeResponse>"""
@@ -483,12 +525,38 @@ DESCRIBE_VOLUMES_MODIFICATIONS_RESPONSE = """
         <item>
             <endTime>{{ modification.end_time }}</endTime>
             <modificationState>completed</modificationState>
-            <originalSize>{{ modification.original_size }}</originalSize>
-            <originalVolumeType>{{ modification.original_volume_type }}</originalVolumeType>
+            {% if modification.original_size %}
+                <originalSize>{{ modification.original_size }}</originalSize>
+            {% endif %}
+            {% if modification.original_volume_type %}
+                <originalVolumeType>{{ modification.original_volume_type }}</originalVolumeType>
+            {% endif %}
+            {% if modification.original_iops %}
+                <originalIops>{{ modification.original_iops }}</originalIops>
+            {% endif %}
+            {% if modification.original_throughput %}
+                <originalThroughput>{{ modification.original_throughput }}</originalThroughput>
+            {% endif %}
+            {% if modification.original_multi_attach_enabled %}
+                <originalMultiAttachEnabled>{{ modification.original_multi_attach_enabled }}</originalMultiAttachEnabled>
+            {% endif %}
             <progress>100</progress>
             <startTime>{{ modification.start_time }}</startTime>
-            <targetSize>{{ modification.target_size }}</targetSize>
-            <targetVolumeType>{{ modification.target_volume_type }}</targetVolumeType>
+            {% if modification.target_size %}
+                <targetSize>{{ modification.target_size }}</targetSize>
+            {% endif %}
+            {% if modification.target_volume_type %}
+                <targetVolumeType>{{ modification.target_volume_type }}</targetVolumeType>
+            {% endif %}
+            {% if modification.target_iops %}
+                <targetIops>{{ modification.target_iops }}</targetIops>
+            {% endif %}
+            {% if modification.target_throughput %}
+                <targetThroughput>{{ modification.target_throughput }}</targetThroughput>
+            {% endif %}
+            {% if modification.target_multi_attach_enabled %}
+                <targetMultiAttachEnabled>{{ modification.target_multi_attach_enabled }}</targetMultiAttachEnabled>
+            {% endif %}
             <volumeId>{{ modification.volume.id }}</volumeId>
         </item>
       {% endfor %}
