@@ -1,8 +1,7 @@
-from datetime import datetime
-from typing import Any, Dict, Iterator, List, Optional, Tuple
+from typing import Any, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
-from moto.core.utils import iso_8601_datetime_without_milliseconds
+from moto.core.utils import utcnow
 from moto.moto_api._internal import mock_random as random
 from moto.utilities.utils import get_partition
 
@@ -54,7 +53,7 @@ DEFAULT_AMI_TYPE = "AL2_x86_64"
 DEFAULT_CAPACITY_TYPE = "ON_DEMAND"
 DEFAULT_DISK_SIZE = "20"
 DEFAULT_INSTANCE_TYPES = ["t3.medium"]
-DEFAULT_NODEGROUP_HEALTH: Dict[str, Any] = {"issues": []}
+DEFAULT_NODEGROUP_HEALTH: dict[str, Any] = {"issues": []}
 DEFAULT_RELEASE_VERSION = "1.19.8-20210414"
 DEFAULT_REMOTE_ACCESS = {"ec2SshKey": "eksKeypair"}
 DEFAULT_SCALING_CONFIG = {"minSize": 2, "maxSize": 2, "desiredSize": 2}
@@ -95,26 +94,27 @@ class Cluster:
         self,
         name: str,
         role_arn: str,
-        resources_vpc_config: Dict[str, Any],
+        resources_vpc_config: dict[str, Any],
         account_id: str,
         region_name: str,
         aws_partition: str,
         version: Optional[str] = None,
-        kubernetes_network_config: Optional[Dict[str, str]] = None,
-        logging: Optional[Dict[str, Any]] = None,
+        kubernetes_network_config: Optional[dict[str, str]] = None,
+        logging: Optional[dict[str, Any]] = None,
         client_request_token: Optional[str] = None,
-        tags: Optional[Dict[str, str]] = None,
-        encryption_config: Optional[List[Dict[str, Any]]] = None,
+        tags: Optional[dict[str, str]] = None,
+        encryption_config: Optional[list[dict[str, Any]]] = None,
+        remote_network_config: Optional[dict[str, list[dict[str, list[str]]]]] = None,
     ):
         if encryption_config is None:
             encryption_config = []
         if tags is None:
-            tags = dict()
+            tags = {}
 
-        self.nodegroups: Dict[str, ManagedNodegroup] = dict()
+        self.nodegroups: dict[str, Nodegroup] = {}
         self.nodegroup_count = 0
 
-        self.fargate_profiles: Dict[str, FargateProfile] = dict()
+        self.fargate_profiles: dict[str, FargateProfile] = {}
         self.fargate_profile_count = 0
 
         self.arn = CLUSTER_ARN_TEMPLATE.format(
@@ -123,8 +123,8 @@ class Cluster:
             region=region_name,
             name=name,
         )
-        self.certificateAuthority = {"data": random.get_random_string(1400)}
-        self.creation_date = iso_8601_datetime_without_milliseconds(datetime.now())
+        self.certificate_authority = {"data": random.get_random_string(1400)}
+        self.created_at = utcnow()
         self.identity = {"oidc": {"issuer": ISSUER_TEMPLATE.format(region=region_name)}}
         self.endpoint = ENDPOINT_TEMPLATE.format(region=region_name)
 
@@ -142,26 +142,10 @@ class Cluster:
         self.resources_vpc_config = resources_vpc_config
         self.role_arn = role_arn
         self.tags = tags
+        self.remote_network_config = remote_network_config
 
-    def __iter__(self) -> Iterator[Tuple[str, Any]]:
-        yield "name", self.name
-        yield "arn", self.arn
-        yield "createdAt", self.creation_date
-        yield "version", self.version
-        yield "endpoint", self.endpoint
-        yield "roleArn", self.role_arn
-        yield "resourcesVpcConfig", self.resources_vpc_config
-        yield "kubernetesNetworkConfig", self.kubernetes_network_config
-        yield "logging", self.logging
-        yield "identity", self.identity
-        yield "status", self.status
-        yield "certificateAuthority", self.certificateAuthority
-        yield "clientRequestToken", self.client_request_token
-        yield "platformVersion", self.platformVersion
-        yield "tags", self.tags
-        yield "encryptionConfig", self.encryption_config
-
-    def isActive(self) -> bool:
+    @property
+    def is_active(self) -> bool:
         return self.status == "ACTIVE"
 
 
@@ -171,20 +155,20 @@ class FargateProfile:
         cluster_name: str,
         fargate_profile_name: str,
         pod_execution_role_arn: str,
-        selectors: List[Dict[str, Any]],
+        selectors: list[dict[str, Any]],
         account_id: str,
         region_name: str,
         aws_partition: str,
         client_request_token: Optional[str] = None,
-        subnets: Optional[List[str]] = None,
-        tags: Optional[Dict[str, str]] = None,
+        subnets: Optional[list[str]] = None,
+        tags: Optional[dict[str, str]] = None,
     ):
         if subnets is None:
-            subnets = list()
+            subnets = []
         if tags is None:
-            tags = dict()
+            tags = {}
 
-        self.created_at = iso_8601_datetime_without_milliseconds(datetime.now())
+        self.created_at = utcnow()
         self.uuid = str(random.uuid4())
         self.fargate_profile_arn = FARGATE_PROFILE_ARN_TEMPLATE.format(
             partition=aws_partition,
@@ -204,46 +188,35 @@ class FargateProfile:
         self.subnets = subnets
         self.tags = tags
 
-    def __iter__(self) -> Iterator[Tuple[str, Any]]:
-        yield "clusterName", self.cluster_name
-        yield "createdAt", self.created_at
-        yield "fargateProfileArn", self.fargate_profile_arn
-        yield "fargateProfileName", self.fargate_profile_name
-        yield "podExecutionRoleArn", self.pod_execution_role_arn
-        yield "selectors", self.selectors
-        yield "subnets", self.subnets
-        yield "status", self.status
-        yield "tags", self.tags
 
-
-class ManagedNodegroup:
+class Nodegroup:
     def __init__(
         self,
         cluster_name: str,
         node_role: str,
         nodegroup_name: str,
-        subnets: List[str],
+        subnets: list[str],
         account_id: str,
         region_name: str,
         aws_partition: str,
-        scaling_config: Optional[Dict[str, int]] = None,
+        scaling_config: Optional[dict[str, int]] = None,
         disk_size: Optional[int] = None,
-        instance_types: Optional[List[str]] = None,
+        instance_types: Optional[list[str]] = None,
         ami_type: Optional[str] = None,
-        remote_access: Optional[Dict[str, Any]] = None,
-        labels: Optional[Dict[str, str]] = None,
-        taints: Optional[List[Dict[str, str]]] = None,
-        tags: Optional[Dict[str, str]] = None,
+        remote_access: Optional[dict[str, Any]] = None,
+        labels: Optional[dict[str, str]] = None,
+        taints: Optional[list[dict[str, str]]] = None,
+        tags: Optional[dict[str, str]] = None,
         client_request_token: Optional[str] = None,
-        launch_template: Optional[Dict[str, str]] = None,
+        launch_template: Optional[dict[str, str]] = None,
         capacity_type: Optional[str] = None,
         version: Optional[str] = None,
         release_version: Optional[str] = None,
     ):
         if tags is None:
-            tags = dict()
+            tags = {}
         if labels is None:
-            labels = dict()
+            labels = {}
         if taints is None:
             taints = []
 
@@ -256,8 +229,8 @@ class ManagedNodegroup:
             nodegroup_name=nodegroup_name,
             uuid=self.uuid,
         )
-        self.creation_date = iso_8601_datetime_without_milliseconds(datetime.now())
-        self.modified_date = iso_8601_datetime_without_milliseconds(datetime.now())
+        self.created_at = utcnow()
+        self.modified_at = utcnow()
         self.health = DEFAULT_NODEGROUP_HEALTH
         self.resources = {
             "autoScalingGroups": [{"name": "eks-" + self.uuid}],
@@ -305,35 +278,11 @@ class ManagedNodegroup:
         except:  # noqa: E722 Do not use bare except
             pass
 
-    def __iter__(self) -> Iterator[Tuple[str, Any]]:
-        yield "nodegroupName", self.nodegroup_name
-        yield "nodegroupArn", self.arn
-        yield "clusterName", self.cluster_name
-        yield "version", self.version
-        yield "releaseVersion", self.release_version
-        yield "createdAt", self.creation_date
-        yield "modifiedAt", self.modified_date
-        yield "status", self.status
-        yield "capacityType", self.capacity_type
-        yield "scalingConfig", self.scaling_config
-        yield "instanceTypes", self.instance_types
-        yield "subnets", self.subnets
-        yield "remoteAccess", self.remote_access
-        yield "amiType", self.ami_type
-        yield "nodeRole", self.node_role
-        yield "labels", self.labels
-        yield "taints", self.taints
-        yield "resources", self.resources
-        yield "diskSize", self.disk_size
-        yield "health", self.health
-        yield "launchTemplate", self.launch_template
-        yield "tags", self.tags
-
 
 class EKSBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.clusters: Dict[str, Cluster] = dict()
+        self.clusters: dict[str, Cluster] = {}
         self.cluster_count = 0
         self.partition = get_partition(region_name)
 
@@ -341,13 +290,14 @@ class EKSBackend(BaseBackend):
         self,
         name: str,
         role_arn: str,
-        resources_vpc_config: Dict[str, Any],
+        resources_vpc_config: dict[str, Any],
         version: Optional[str] = None,
-        kubernetes_network_config: Optional[Dict[str, str]] = None,
-        logging: Optional[Dict[str, Any]] = None,
+        kubernetes_network_config: Optional[dict[str, str]] = None,
+        logging: Optional[dict[str, Any]] = None,
         client_request_token: Optional[str] = None,
-        tags: Optional[Dict[str, str]] = None,
-        encryption_config: Optional[List[Dict[str, Any]]] = None,
+        tags: Optional[dict[str, str]] = None,
+        encryption_config: Optional[list[dict[str, Any]]] = None,
+        remote_network_config: Optional[dict[str, list[dict[str, list[str]]]]] = None,
     ) -> Cluster:
         if name in self.clusters:
             # Cluster exists.
@@ -369,6 +319,7 @@ class EKSBackend(BaseBackend):
             client_request_token=client_request_token,
             tags=tags,
             encryption_config=encryption_config,
+            remote_network_config=remote_network_config,
             account_id=self.account_id,
             region_name=self.region_name,
             aws_partition=self.partition,
@@ -381,11 +332,11 @@ class EKSBackend(BaseBackend):
         self,
         fargate_profile_name: str,
         cluster_name: str,
-        selectors: List[Dict[str, Any]],
+        selectors: list[dict[str, Any]],
         pod_execution_role_arn: str,
-        subnets: Optional[List[str]] = None,
+        subnets: Optional[list[str]] = None,
         client_request_token: Optional[str] = None,
-        tags: Optional[Dict[str, str]] = None,
+        tags: Optional[dict[str, str]] = None,
     ) -> FargateProfile:
         try:
             # Cluster exists.
@@ -407,7 +358,7 @@ class EKSBackend(BaseBackend):
                 addonName=None,
                 message=FARGATE_PROFILE_EXISTS_MSG,
             )
-        if not cluster.isActive():
+        if not cluster.is_active:
             raise InvalidRequestException(
                 message=CLUSTER_NOT_READY_MSG.format(clusterName=cluster_name)
             )
@@ -436,21 +387,21 @@ class EKSBackend(BaseBackend):
         cluster_name: str,
         node_role: str,
         nodegroup_name: str,
-        subnets: List[str],
-        scaling_config: Optional[Dict[str, int]] = None,
+        subnets: list[str],
+        scaling_config: Optional[dict[str, int]] = None,
         disk_size: Optional[int] = None,
-        instance_types: Optional[List[str]] = None,
+        instance_types: Optional[list[str]] = None,
         ami_type: Optional[str] = None,
-        remote_access: Optional[Dict[str, Any]] = None,
-        labels: Optional[Dict[str, str]] = None,
-        taints: Optional[List[Dict[str, str]]] = None,
-        tags: Optional[Dict[str, str]] = None,
+        remote_access: Optional[dict[str, Any]] = None,
+        labels: Optional[dict[str, str]] = None,
+        taints: Optional[list[dict[str, str]]] = None,
+        tags: Optional[dict[str, str]] = None,
         client_request_token: Optional[str] = None,
-        launch_template: Optional[Dict[str, str]] = None,
+        launch_template: Optional[dict[str, str]] = None,
         capacity_type: Optional[str] = None,
         version: Optional[str] = None,
         release_version: Optional[str] = None,
-    ) -> ManagedNodegroup:
+    ) -> Nodegroup:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -473,7 +424,7 @@ class EKSBackend(BaseBackend):
                     nodegroupName=nodegroup_name, clusterName=cluster_name
                 ),
             )
-        if not cluster.isActive():
+        if not cluster.is_active:
             raise InvalidRequestException(
                 message=CLUSTER_NOT_READY_MSG.format(clusterName=cluster_name)
             )
@@ -481,7 +432,7 @@ class EKSBackend(BaseBackend):
             validate_launch_template_combination(disk_size, remote_access)
         validate_role_arn(node_role)
 
-        nodegroup = ManagedNodegroup(
+        nodegroup = Nodegroup(
             cluster_name=cluster_name,
             node_role=node_role,
             nodegroup_name=nodegroup_name,
@@ -552,9 +503,7 @@ class EKSBackend(BaseBackend):
                 ),
             )
 
-    def describe_nodegroup(
-        self, cluster_name: str, nodegroup_name: str
-    ) -> ManagedNodegroup:
+    def describe_nodegroup(self, cluster_name: str, nodegroup_name: str) -> Nodegroup:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -631,9 +580,7 @@ class EKSBackend(BaseBackend):
         cluster.fargate_profile_count -= 1
         return deleted_fargate_profile
 
-    def delete_nodegroup(
-        self, cluster_name: str, nodegroup_name: str
-    ) -> ManagedNodegroup:
+    def delete_nodegroup(self, cluster_name: str, nodegroup_name: str) -> Nodegroup:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -662,7 +609,7 @@ class EKSBackend(BaseBackend):
         cluster.nodegroup_count -= 1
         return result
 
-    def tag_resource(self, resource_arn: str, tags: Dict[str, str]) -> None:
+    def tag_resource(self, resource_arn: str, tags: dict[str, str]) -> None:
         """
         This function currently will tag an EKS cluster only.  It does not tag a managed node group
         """
@@ -684,7 +631,7 @@ class EKSBackend(BaseBackend):
             )
         cluster.tags.update(tags)
 
-    def untag_resource(self, resource_arn: str, tag_keys: List[str]) -> None:
+    def untag_resource(self, resource_arn: str, tag_keys: list[str]) -> None:
         """
         This function currently will remove tags on an EKS cluster only.  It does not remove tags from a managed node group
         """
@@ -710,7 +657,7 @@ class EKSBackend(BaseBackend):
             if name in cluster.tags:
                 del cluster.tags[name]
 
-    def list_tags_for_resource(self, resource_arn: str) -> Dict[str, str]:
+    def list_tags_for_resource(self, resource_arn: str) -> dict[str, str]:
         """
         This function currently will list tags on an EKS cluster only.  It does not list tags from a managed node group
         """
@@ -734,12 +681,12 @@ class EKSBackend(BaseBackend):
 
     def list_clusters(
         self, max_results: int, next_token: Optional[str]
-    ) -> Tuple[List[Cluster], Optional[Cluster]]:
+    ) -> tuple[list[Cluster], Optional[Cluster]]:
         return paginated_list(list(self.clusters.keys()), max_results, next_token)
 
     def list_fargate_profiles(
         self, cluster_name: str, max_results: int, next_token: Optional[str]
-    ) -> Tuple[List[FargateProfile], Optional[FargateProfile]]:
+    ) -> tuple[list[FargateProfile], Optional[FargateProfile]]:
         cluster = self.clusters[cluster_name]
         return paginated_list(
             list(cluster.fargate_profiles.keys()), max_results, next_token
@@ -747,14 +694,46 @@ class EKSBackend(BaseBackend):
 
     def list_nodegroups(
         self, cluster_name: str, max_results: int, next_token: Optional[str]
-    ) -> Tuple[List[ManagedNodegroup], Optional[ManagedNodegroup]]:
+    ) -> tuple[list[Nodegroup], Optional[Nodegroup]]:
         cluster = self.clusters[cluster_name]
         return paginated_list(list(cluster.nodegroups.keys()), max_results, next_token)
 
+    def update_cluster_config(
+        self,
+        name: str,
+        resources_vpc_config: dict[str, Any],
+        logging: Optional[dict[str, Any]] = None,
+        client_request_token: Optional[str] = None,
+        kubernetes_network_config: Optional[dict[str, str]] = None,
+        remote_network_config: Optional[dict[str, list[dict[str, list[str]]]]] = None,
+    ) -> Cluster:
+        cluster = self.clusters.get(name)
+        if cluster:
+            if resources_vpc_config:
+                self.clusters[name].resources_vpc_config = resources_vpc_config
+            if logging:
+                self.clusters[name].logging = logging
+            if client_request_token:
+                self.clusters[name].client_request_token = client_request_token
+            if kubernetes_network_config:
+                self.clusters[
+                    name
+                ].kubernetes_network_config = kubernetes_network_config
+            if remote_network_config:
+                self.clusters[name].remote_network_config = remote_network_config
+            return cluster
+        raise ResourceNotFoundException(
+            clusterName=name,
+            nodegroupName=None,
+            fargateProfileName=None,
+            addonName=None,
+            message=CLUSTER_NOT_FOUND_MSG.format(clusterName=name),
+        )
+
 
 def paginated_list(
-    full_list: List[Any], max_results: int, next_token: Optional[str]
-) -> Tuple[List[Any], Optional[Any]]:
+    full_list: list[Any], max_results: int, next_token: Optional[str]
+) -> tuple[list[Any], Optional[Any]]:
     """
     Returns a tuple containing a slice of the full list
     starting at next_token and ending with at most the
@@ -785,7 +764,7 @@ def validate_safe_to_delete(cluster: Cluster) -> None:
 
 
 def validate_launch_template_combination(
-    disk_size: Optional[int], remote_access: Optional[Dict[str, Any]]
+    disk_size: Optional[int], remote_access: Optional[dict[str, Any]]
 ) -> None:
     if not (disk_size or remote_access):
         return
@@ -797,7 +776,7 @@ def validate_launch_template_combination(
     )
 
 
-def _validate_fargate_profile_selectors(selectors: List[Dict[str, Any]]) -> None:
+def _validate_fargate_profile_selectors(selectors: list[dict[str, Any]]) -> None:
     def raise_exception(message: str) -> None:
         raise InvalidParameterException(
             clusterName=None,
