@@ -1,6 +1,6 @@
 import json
 import re
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
@@ -60,7 +60,7 @@ class FakeOrganization(BaseModel):
             partition, self.master_account_id, self.id
         )
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "Organization": {
                 "Id": self.id,
@@ -88,7 +88,7 @@ class FakeAccount(BaseModel):
         self.status = "ACTIVE"
         self.joined_method = "CREATED"
         self.parent_id = organization.root_id
-        self.attached_policies: List[FakePolicy] = []
+        self.attached_policies: list[FakePolicy] = []
         self.tags = {tag["Key"]: tag["Value"] for tag in kwargs.get("Tags", [])}
 
         role_name = kwargs.get("RoleName", "OrganizationAccountAccessRole")
@@ -128,7 +128,7 @@ class FakeAccount(BaseModel):
         )
 
     @property
-    def create_account_status(self) -> Dict[str, Any]:  # type: ignore[misc]
+    def create_account_status(self) -> dict[str, Any]:  # type: ignore[misc]
         return {
             "CreateAccountStatus": {
                 "Id": self.create_account_status_id,
@@ -140,7 +140,7 @@ class FakeAccount(BaseModel):
             }
         }
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "Id": self.id,
             "Arn": self.arn,
@@ -169,7 +169,7 @@ class FakeOrganizationalUnit(BaseModel):
         self.name = kwargs.get("Name")
         self.parent_id = kwargs.get("ParentId")
         self._arn_format = utils.OU_ARN_FORMAT
-        self.attached_policies: List[FakePolicy] = []
+        self.attached_policies: list[FakePolicy] = []
         self.tags = {tag["Key"]: tag["Value"] for tag in kwargs.get("Tags", [])}
 
     @property
@@ -179,7 +179,7 @@ class FakeOrganizationalUnit(BaseModel):
             partition, self.master_account_id, self.organization_id, self.id
         )
 
-    def describe(self) -> Dict[str, Dict[str, Any]]:
+    def describe(self) -> dict[str, dict[str, Any]]:
         return {
             "OrganizationalUnit": {"Id": self.id, "Arn": self.arn, "Name": self.name}
         }
@@ -198,12 +198,12 @@ class FakeRoot(FakeOrganizationalUnit):
         self.type = "ROOT"
         self.id = organization.root_id
         self.name = "Root"
-        self.policy_types: List[Dict[str, str]] = []
+        self.policy_types: list[dict[str, str]] = []
         self._arn_format = utils.ROOT_ARN_FORMAT
         self.attached_policies = []
         self.tags = {tag["Key"]: tag["Value"] for tag in kwargs.get("Tags", [])}
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "Id": self.id,
             "Arn": self.arn,
@@ -248,7 +248,7 @@ class FakePolicy(BaseModel):
         self.region = organization.region
         self.organization_id = organization.id
         self.master_account_id = organization.master_account_id
-        self.attachments: List[Any] = []
+        self.attachments: list[Any] = []
         self.tags = {tag["Key"]: tag["Value"] for tag in kwargs.get("Tags", [])}
 
         if not FakePolicy.supported_policy_type(self.type):
@@ -271,7 +271,7 @@ class FakePolicy(BaseModel):
             partition, self.master_account_id, self.organization_id, self.id
         )
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "Policy": {
                 "PolicySummary": {
@@ -344,7 +344,7 @@ class FakeServiceAccess(BaseModel):
         self.service_principal = kwargs["ServicePrincipal"]
         self.date_enabled = utcnow()
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         return {
             "ServicePrincipal": self.service_principal,
             "DateEnabled": unix_time(self.date_enabled),
@@ -370,7 +370,7 @@ class FakeDelegatedAdministrator(BaseModel):
     def __init__(self, account: FakeAccount):
         self.account = account
         self.enabled_date = utcnow()
-        self.services: Dict[str, Any] = {}
+        self.services: dict[str, Any] = {}
 
     def add_service_principal(self, service_principal: str) -> None:
         if service_principal in self.services:
@@ -394,7 +394,7 @@ class FakeDelegatedAdministrator(BaseModel):
 
         self.services.pop(service_principal)
 
-    def describe(self) -> Dict[str, Any]:
+    def describe(self) -> dict[str, Any]:
         admin = self.account.describe()
         admin["DelegationEnabledDate"] = unix_time(self.enabled_date)
 
@@ -412,11 +412,11 @@ class OrganizationsBackend(BaseBackend):
 
     def _reset(self) -> None:
         self.org: Optional[FakeOrganization] = None
-        self.accounts: List[FakeAccount] = []
-        self.ou: List[FakeOrganizationalUnit] = []
-        self.policies: List[FakePolicy] = []
-        self.services: List[Dict[str, Any]] = []
-        self.admins: List[FakeDelegatedAdministrator] = []
+        self.accounts: list[FakeAccount] = []
+        self.ou: list[FakeOrganizationalUnit] = []
+        self.policies: list[FakePolicy] = []
+        self.services: list[dict[str, Any]] = []
+        self.admins: list[FakeDelegatedAdministrator] = []
 
     def _get_root_by_id(self, root_id: str) -> FakeRoot:
         root = next((ou for ou in self.ou if ou.id == root_id), None)
@@ -425,7 +425,7 @@ class OrganizationsBackend(BaseBackend):
 
         return root  # type: ignore[return-value]
 
-    def create_organization(self, region: str, **kwargs: Any) -> Dict[str, Any]:
+    def create_organization(self, region: str, **kwargs: Any) -> dict[str, Any]:
         if self.org or self.account_id in organizations_backends.master_accounts:
             raise AlreadyInOrganizationException
 
@@ -460,7 +460,7 @@ class OrganizationsBackend(BaseBackend):
         self.attach_policy(PolicyId=default_policy.id, TargetId=master_account.id)
         return self.org.describe()
 
-    def describe_organization(self) -> Dict[str, Any]:
+    def describe_organization(self) -> dict[str, Any]:
         if self.org:
             # This is a master account
             return self.org.describe()
@@ -483,11 +483,11 @@ class OrganizationsBackend(BaseBackend):
 
         self._reset()
 
-    def list_roots(self) -> Dict[str, Any]:
+    def list_roots(self) -> dict[str, Any]:
         if self.org:
-            return dict(
-                Roots=[ou.describe() for ou in self.ou if isinstance(ou, FakeRoot)]
-            )
+            return {
+                "Roots": [ou.describe() for ou in self.ou if isinstance(ou, FakeRoot)]
+            }
 
         if self.account_id in organizations_backends.master_accounts:
             master_account_id, partition = organizations_backends.master_accounts[
@@ -497,7 +497,7 @@ class OrganizationsBackend(BaseBackend):
 
         raise AWSOrganizationsNotInUseException
 
-    def create_organizational_unit(self, **kwargs: Any) -> Dict[str, Any]:
+    def create_organizational_unit(self, **kwargs: Any) -> dict[str, Any]:
         new_ou = FakeOrganizationalUnit(self.org, **kwargs)  # type: ignore
         self.ou.append(new_ou)
         self.attach_policy(PolicyId=utils.DEFAULT_POLICY_ID, TargetId=new_ou.id)
@@ -509,7 +509,7 @@ class OrganizationsBackend(BaseBackend):
         )
         self.ou.remove(ou_to_delete)
 
-    def update_organizational_unit(self, **kwargs: Any) -> Dict[str, Any]:
+    def update_organizational_unit(self, **kwargs: Any) -> dict[str, Any]:
         for ou in self.ou:
             if ou.name == kwargs["Name"]:
                 raise DuplicateOrganizationalUnitException
@@ -535,18 +535,18 @@ class OrganizationsBackend(BaseBackend):
             )
         return parent_id
 
-    def describe_organizational_unit(self, **kwargs: Any) -> Dict[str, Any]:
+    def describe_organizational_unit(self, **kwargs: Any) -> dict[str, Any]:
         ou = self.get_organizational_unit_by_id(kwargs["OrganizationalUnitId"])
         return ou.describe()
 
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_organizational_units_for_parent(
         self, parent_id: str
-    ) -> List[FakeOrganizationalUnit]:
+    ) -> list[FakeOrganizationalUnit]:
         parent_id = self.validate_parent_id(parent_id)
         return [ou for ou in self.ou if ou.parent_id == parent_id]
 
-    def create_account(self, **kwargs: Any) -> Dict[str, Any]:
+    def create_account(self, **kwargs: Any) -> dict[str, Any]:
         if self.org is None:
             raise AWSOrganizationsNotInUseException
 
@@ -591,17 +591,17 @@ class OrganizationsBackend(BaseBackend):
             raise AccountNotFoundException
         return account
 
-    def describe_account(self, **kwargs: Any) -> Dict[str, Any]:
+    def describe_account(self, **kwargs: Any) -> dict[str, Any]:
         account = self.get_account_by_id(kwargs["AccountId"])
-        return dict(Account=account.describe())
+        return {"Account": account.describe()}
 
-    def describe_create_account_status(self, **kwargs: Any) -> Dict[str, Any]:
+    def describe_create_account_status(self, **kwargs: Any) -> dict[str, Any]:
         account = self.get_account_by_attr(
             "create_account_status_id", kwargs["CreateAccountRequestId"]
         )
         return account.create_account_status
 
-    def list_create_account_status(self, **kwargs: Any) -> Dict[str, Any]:
+    def list_create_account_status(self, **kwargs: Any) -> dict[str, Any]:
         requested_states = kwargs.get("States")
         if not requested_states:
             requested_states = ["IN_PROGRESS", "SUCCEEDED", "FAILED"]
@@ -620,15 +620,15 @@ class OrganizationsBackend(BaseBackend):
         next_token = None
         if max_results and len(accountStatuses) > (start + max_results):
             next_token = str(len(accounts_resp))
-        return dict(CreateAccountStatuses=accounts_resp, NextToken=next_token)
+        return {"CreateAccountStatuses": accounts_resp, "NextToken": next_token}
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_accounts(self) -> List[FakeAccount]:
+    def list_accounts(self) -> list[FakeAccount]:
         accounts = [account.describe() for account in self.accounts]
         return sorted(accounts, key=lambda x: x["JoinedTimestamp"])  # type: ignore
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_accounts_for_parent(self, parent_id: str) -> List[FakeAccount]:
+    def list_accounts_for_parent(self, parent_id: str) -> list[FakeAccount]:
         parent_id = self.validate_parent_id(parent_id)
         accounts = [
             account for account in self.accounts if account.parent_id == parent_id
@@ -642,36 +642,36 @@ class OrganizationsBackend(BaseBackend):
         index = self.accounts.index(account)
         self.accounts[index].parent_id = new_parent_id
 
-    def list_parents(self, **kwargs: Any) -> Dict[str, Any]:
+    def list_parents(self, **kwargs: Any) -> dict[str, Any]:
         if re.compile(r"[0-9]{12}").match(kwargs["ChildId"]):
             child_object: Any = self.get_account_by_id(kwargs["ChildId"])
         else:
             child_object = self.get_organizational_unit_by_id(kwargs["ChildId"])
-        return dict(
-            Parents=[
+        return {
+            "Parents": [
                 {"Id": ou.id, "Type": ou.type}
                 for ou in self.ou
                 if ou.id == child_object.parent_id
             ]
-        )
+        }
 
-    def list_children(self, **kwargs: Any) -> Dict[str, Any]:
+    def list_children(self, **kwargs: Any) -> dict[str, Any]:
         parent_id = self.validate_parent_id(kwargs["ParentId"])
         if kwargs["ChildType"] == "ACCOUNT":
-            obj_list: List[Any] = self.accounts
+            obj_list: list[Any] = self.accounts
         elif kwargs["ChildType"] == "ORGANIZATIONAL_UNIT":
             obj_list = self.ou
         else:
             raise InvalidInputException("You specified an invalid value.")
-        return dict(
-            Children=[
+        return {
+            "Children": [
                 {"Id": obj.id, "Type": kwargs["ChildType"]}
                 for obj in obj_list
                 if obj.parent_id == parent_id
             ]
-        )
+        }
 
-    def create_policy(self, **kwargs: Any) -> Dict[str, Any]:
+    def create_policy(self, **kwargs: Any) -> dict[str, Any]:
         new_policy = FakePolicy(self.org, **kwargs)  # type: ignore
         for policy in self.policies:
             if kwargs["Name"] == policy.name:
@@ -679,7 +679,7 @@ class OrganizationsBackend(BaseBackend):
         self.policies.append(new_policy)
         return new_policy.describe()
 
-    def describe_policy(self, **kwargs: Any) -> Dict[str, Any]:
+    def describe_policy(self, **kwargs: Any) -> dict[str, Any]:
         if re.compile(utils.POLICY_ID_REGEX).match(kwargs["PolicyId"]):
             policy = next(
                 (p for p in self.policies if p.id == kwargs["PolicyId"]), None
@@ -702,7 +702,7 @@ class OrganizationsBackend(BaseBackend):
             )
         return policy
 
-    def update_policy(self, **kwargs: Any) -> Dict[str, Any]:
+    def update_policy(self, **kwargs: Any) -> dict[str, Any]:
         policy = self.get_policy_by_id(kwargs["PolicyId"])
         policy.name = kwargs.get("Name", policy.name)
         policy.description = kwargs.get("Description", policy.description)
@@ -737,10 +737,10 @@ class OrganizationsBackend(BaseBackend):
         else:
             raise InvalidInputException("You specified an invalid value.")
 
-    def list_policies(self) -> Dict[str, Any]:
-        return dict(
-            Policies=[p.describe()["Policy"]["PolicySummary"] for p in self.policies]
-        )
+    def list_policies(self) -> dict[str, Any]:
+        return {
+            "Policies": [p.describe()["Policy"]["PolicySummary"] for p in self.policies]
+        }
 
     def delete_policy(self, **kwargs: Any) -> None:
         for idx, policy in enumerate(self.policies):
@@ -756,7 +756,7 @@ class OrganizationsBackend(BaseBackend):
             "We can't find a policy with the PolicyId that you specified.",
         )
 
-    def list_policies_for_target(self, **kwargs: Any) -> Dict[str, Any]:
+    def list_policies_for_target(self, **kwargs: Any) -> dict[str, Any]:
         _filter = kwargs["Filter"]
 
         if re.match(utils.ROOT_ID_REGEX, kwargs["TargetId"]):
@@ -789,13 +789,13 @@ class OrganizationsBackend(BaseBackend):
                 f"The {_filter} policy type has not been implemented"
             )
 
-        return dict(
-            Policies=[
+        return {
+            "Policies": [
                 p.describe()["Policy"]["PolicySummary"]
                 for p in obj.attached_policies
                 if p.type == _filter
             ]
-        )
+        }
 
     def _get_resource_for_tagging(self, resource_id: str) -> Any:
         if utils.fullmatch(
@@ -816,7 +816,7 @@ class OrganizationsBackend(BaseBackend):
 
         return resource
 
-    def list_targets_for_policy(self, **kwargs: Any) -> Dict[str, Any]:
+    def list_targets_for_policy(self, **kwargs: Any) -> dict[str, Any]:
         if re.compile(utils.POLICY_ID_REGEX).match(kwargs["PolicyId"]):
             policy = next(
                 (p for p in self.policies if p.id == kwargs["PolicyId"]), None
@@ -831,17 +831,17 @@ class OrganizationsBackend(BaseBackend):
             {"TargetId": obj.id, "Arn": obj.arn, "Name": obj.name, "Type": obj.type}
             for obj in policy.attachments
         ]
-        return dict(Targets=objects)
+        return {"Targets": objects}
 
     def tag_resource(self, **kwargs: Any) -> None:
         resource = self._get_resource_for_tagging(kwargs["ResourceId"])
         new_tags = {tag["Key"]: tag["Value"] for tag in kwargs["Tags"]}
         resource.tags.update(new_tags)
 
-    def list_tags_for_resource(self, **kwargs: str) -> Dict[str, Any]:
+    def list_tags_for_resource(self, **kwargs: str) -> dict[str, Any]:
         resource = self._get_resource_for_tagging(kwargs["ResourceId"])
         tags = [{"Key": key, "Value": value} for key, value in resource.tags.items()]
-        return dict(Tags=tags)
+        return {"Tags": tags}
 
     def untag_resource(self, **kwargs: Any) -> None:
         resource = self._get_resource_for_tagging(kwargs["ResourceId"])
@@ -860,8 +860,8 @@ class OrganizationsBackend(BaseBackend):
 
         self.services.append(service.describe())
 
-    def list_aws_service_access_for_organization(self) -> Dict[str, Any]:
-        return dict(EnabledServicePrincipals=self.services)
+    def list_aws_service_access_for_organization(self) -> dict[str, Any]:
+        return {"EnabledServicePrincipals": self.services}
 
     def disable_aws_service_access(self, **kwargs: str) -> None:
         if not FakeServiceAccess.trusted_service(kwargs["ServicePrincipal"]):
@@ -900,7 +900,7 @@ class OrganizationsBackend(BaseBackend):
 
         admin.add_service_principal(kwargs["ServicePrincipal"])
 
-    def list_delegated_administrators(self, **kwargs: str) -> Dict[str, Any]:
+    def list_delegated_administrators(self, **kwargs: str) -> dict[str, Any]:
         admins = self.admins
         service = kwargs.get("ServicePrincipal")
 
@@ -914,9 +914,9 @@ class OrganizationsBackend(BaseBackend):
 
         delegated_admins = [admin.describe() for admin in admins]
 
-        return dict(DelegatedAdministrators=delegated_admins)
+        return {"DelegatedAdministrators": delegated_admins}
 
-    def list_delegated_services_for_account(self, **kwargs: str) -> Dict[str, Any]:
+    def list_delegated_services_for_account(self, **kwargs: str) -> dict[str, Any]:
         admin = next(
             (admin for admin in self.admins if admin.account.id == kwargs["AccountId"]),
             None,
@@ -935,9 +935,9 @@ class OrganizationsBackend(BaseBackend):
 
             raise AWSOrganizationsNotInUseException
 
-        services = [service for service in admin.services.values()]
+        services = list(admin.services.values())
 
-        return dict(DelegatedServices=services)
+        return {"DelegatedServices": services}
 
     def deregister_delegated_administrator(self, **kwargs: str) -> None:
         account_id = kwargs["AccountId"]
@@ -971,19 +971,19 @@ class OrganizationsBackend(BaseBackend):
         if not admin.services:
             self.admins.remove(admin)
 
-    def enable_policy_type(self, **kwargs: str) -> Dict[str, Any]:
+    def enable_policy_type(self, **kwargs: str) -> dict[str, Any]:
         root = self._get_root_by_id(kwargs["RootId"])
 
         root.add_policy_type(kwargs["PolicyType"])
 
-        return dict(Root=root.describe())
+        return {"Root": root.describe()}
 
-    def disable_policy_type(self, **kwargs: str) -> Dict[str, Any]:
+    def disable_policy_type(self, **kwargs: str) -> dict[str, Any]:
         root = self._get_root_by_id(kwargs["RootId"])
 
         root.remove_policy_type(kwargs["PolicyType"])
 
-        return dict(Root=root.describe())
+        return {"Root": root.describe()}
 
     def detach_policy(self, **kwargs: str) -> None:
         policy = self.get_policy_by_id(kwargs["PolicyId"])
@@ -1037,12 +1037,12 @@ class OrganizationsBackendDict(BackendDict[OrganizationsBackend]):
         backend: Any,
         service_name: str,
         use_boto3_regions: bool = True,
-        additional_regions: Optional[List[str]] = None,
+        additional_regions: Optional[list[str]] = None,
     ):
         super().__init__(backend, service_name, use_boto3_regions, additional_regions)
 
         # Maps member account IDs to the (master account ID, partition) which owns the organisation
-        self.master_accounts: Dict[str, Tuple[str, str]] = {}
+        self.master_accounts: dict[str, tuple[str, str]] = {}
 
 
 organizations_backends = OrganizationsBackendDict(
