@@ -1,7 +1,7 @@
 import datetime
 import json
 import time
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Optional, Union
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
@@ -37,7 +37,7 @@ MAX_RESULTS_DEFAULT = 100
 
 
 def filter_primary_region(
-    secret: Union["FakeSecret", "ReplicaSecret"], values: List[str]
+    secret: Union["FakeSecret", "ReplicaSecret"], values: list[str]
 ) -> bool:
     if isinstance(secret, FakeSecret):
         return len(secret.replicas) > 0 and secret.region in values
@@ -56,12 +56,12 @@ _filter_functions = {
 }
 
 
-def filter_keys() -> List[str]:
+def filter_keys() -> list[str]:
     return list(_filter_functions.keys())
 
 
 def _matches(
-    secret: Union["FakeSecret", "ReplicaSecret"], filters: List[Dict[str, Any]]
+    secret: Union["FakeSecret", "ReplicaSecret"], filters: list[dict[str, Any]]
 ) -> bool:
     is_match = True
 
@@ -79,17 +79,17 @@ class FakeSecret(BaseModel):
         account_id: str,
         region_name: str,
         secret_id: str,
-        secret_version: Dict[str, Any],
+        secret_version: dict[str, Any],
         version_id: str,
         secret_string: Optional[str] = None,
         secret_binary: Optional[str] = None,
         description: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
         kms_key_id: Optional[str] = None,
-        version_stages: Optional[List[str]] = None,
+        version_stages: Optional[list[str]] = None,
         last_changed_date: Optional[int] = None,
         created_date: Optional[int] = None,
-        replica_regions: Optional[List[Dict[str, str]]] = None,
+        replica_regions: Optional[list[dict[str, str]]] = None,
         force_overwrite: bool = False,
     ):
         self.secret_id = secret_id
@@ -117,7 +117,7 @@ class FakeSecret(BaseModel):
         self.next_rotation_date: Optional[int] = None
         self.last_rotation_date: Optional[int] = None
 
-        self.versions: Dict[str, Dict[str, Any]] = {}
+        self.versions: dict[str, dict[str, Any]] = {}
         if secret_string or secret_binary:
             self.versions = {version_id: secret_version}
             self.set_default_version_id(version_id)
@@ -136,14 +136,14 @@ class FakeSecret(BaseModel):
         return None
 
     def create_replicas(
-        self, replica_regions: List[Dict[str, str]], force_overwrite: bool
-    ) -> List["ReplicaSecret"]:
+        self, replica_regions: list[dict[str, str]], force_overwrite: bool
+    ) -> list["ReplicaSecret"]:
         # Validate first, before we create anything
         for replica_config in replica_regions or []:
             if replica_config["Region"] == self.region:
                 raise InvalidParameterException("Invalid replica region.")
 
-        replicas: List[ReplicaSecret] = []
+        replicas: list[ReplicaSecret] = []
         for replica_config in replica_regions or []:
             replica_region = replica_config["Region"]
             backend = secretsmanager_backends[self.account_id][replica_region]
@@ -164,7 +164,7 @@ class FakeSecret(BaseModel):
     def update(
         self,
         description: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
         kms_key_id: Optional[str] = None,
         last_changed_date: Optional[int] = None,
     ) -> None:
@@ -180,7 +180,7 @@ class FakeSecret(BaseModel):
         self.default_version_id = version_id
 
     def reset_default_version(
-        self, secret_version: Dict[str, Any], version_id: str
+        self, secret_version: dict[str, Any], version_id: str
     ) -> None:
         # remove all old AWSPREVIOUS stages
         for old_version in self.versions.values():
@@ -198,7 +198,7 @@ class FakeSecret(BaseModel):
         self.default_version_id = version_id
 
     def remove_version_stages_from_old_versions(
-        self, version_stages: List[str]
+        self, version_stages: list[str]
     ) -> None:
         for version_stage in version_stages:
             for old_version in self.versions.values():
@@ -222,7 +222,7 @@ class FakeSecret(BaseModel):
     ) -> str:
         if not version_id:
             version_id = self.default_version_id
-        dct: Dict[str, Any] = {
+        dct: dict[str, Any] = {
             "ARN": self.arn,
             "Name": self.name,
         }
@@ -234,10 +234,10 @@ class FakeSecret(BaseModel):
             dct["ReplicationStatus"] = [replica.config for replica in self.replicas]
         return json.dumps(dct)
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         version_id_to_stages = self._form_version_ids_to_stages()
 
-        dct: Dict[str, Any] = {
+        dct: dict[str, Any] = {
             "ARN": self.arn,
             "Name": self.name,
             "LastChangedDate": self.last_changed_date,
@@ -278,7 +278,7 @@ class FakeSecret(BaseModel):
             dct["ReplicationStatus"] = [replica.config for replica in self.replicas]
         return dct
 
-    def _form_version_ids_to_stages(self) -> Dict[str, str]:
+    def _form_version_ids_to_stages(self) -> dict[str, str]:
         version_id_to_stages = {}
         for key, value in self.versions.items():
             version_id_to_stages[key] = value["version_stages"]
@@ -310,7 +310,7 @@ class ReplicaSecret:
     def is_deleted(self) -> bool:
         return False
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         dct = self.source.to_dict()
         dct["ARN"] = self.arn
         dct["PrimaryRegion"] = self.source.region
@@ -321,7 +321,7 @@ class ReplicaSecret:
         return self.source.default_version_id
 
     @property
-    def versions(self) -> Dict[str, Dict[str, Any]]:  # type: ignore[misc]
+    def versions(self) -> dict[str, dict[str, Any]]:  # type: ignore[misc]
         return self.source.versions
 
     @property
@@ -337,7 +337,7 @@ class ReplicaSecret:
         return self.source.description
 
     @property
-    def tags(self) -> Optional[List[Dict[str, str]]]:
+    def tags(self) -> Optional[list[dict[str, str]]]:
         return self.source.tags
 
     @property
@@ -345,7 +345,7 @@ class ReplicaSecret:
         return self.source.owning_service
 
 
-class SecretsStore(Dict[str, Union[FakeSecret, ReplicaSecret]]):
+class SecretsStore(dict[str, Union[FakeSecret, ReplicaSecret]]):
     # Parameters to this dictionary can be three possible values:
     # names, full ARNs, and partial ARNs
     # Every retrieval method should check which type of input it receives
@@ -425,10 +425,8 @@ class SecretsManagerBackend(BaseBackend):
             # This response doesn't make much sense for  `CancelRotateSecret`, but this is what AWS has documented ...
             # https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_CancelRotateSecret.html
             raise InvalidRequestException(
-                (
-                    "You tried to enable rotation on a secret that doesn't already have a Lambda function ARN configured"
-                    "and you didn't include such an ARN as a parameter in this call."
-                )
+                "You tried to enable rotation on a secret that doesn't already have a Lambda function ARN configured"
+                "and you didn't include such an ARN as a parameter in this call."
             )
 
         secret.rotation_enabled = False
@@ -436,7 +434,7 @@ class SecretsManagerBackend(BaseBackend):
 
     def get_secret_value(
         self, secret_id: str, version_id: str, version_stage: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
 
@@ -500,13 +498,13 @@ class SecretsManagerBackend(BaseBackend):
 
     def batch_get_secret_value(
         self,
-        secret_id_list: Optional[List[str]] = None,
-        filters: Optional[List[Dict[str, Any]]] = None,
+        secret_id_list: Optional[list[str]] = None,
+        filters: Optional[list[dict[str, Any]]] = None,
         max_results: Optional[int] = None,
         next_token: Optional[str] = None,
-    ) -> Tuple[List[Dict[str, Any]], List[Any], Optional[str]]:
+    ) -> tuple[list[dict[str, Any]], list[Any], Optional[str]]:
         secret_list = []
-        errors: List[Any] = []
+        errors: list[Any] = []
         if secret_id_list and filters:
             raise InvalidParameterException(
                 "Either 'SecretIdList' or 'Filters' must be provided, but not both."
@@ -592,10 +590,10 @@ class SecretsManagerBackend(BaseBackend):
         secret_string: Optional[str],
         secret_binary: Optional[str],
         description: Optional[str],
-        tags: Optional[List[Dict[str, str]]],
+        tags: Optional[list[dict[str, str]]],
         kms_key_id: Optional[str],
         client_request_token: Optional[str],
-        replica_regions: List[Dict[str, str]],
+        replica_regions: list[dict[str, str]],
         force_overwrite: bool,
     ) -> str:
         existing_secret = self._check_with_existing_secrets_and_versions(
@@ -671,13 +669,13 @@ class SecretsManagerBackend(BaseBackend):
         secret_string: Optional[str] = None,
         secret_binary: Optional[str] = None,
         description: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
         kms_key_id: Optional[str] = None,
         version_id: Optional[str] = None,
-        version_stages: Optional[List[str]] = None,
-        replica_regions: Optional[List[Dict[str, str]]] = None,
+        version_stages: Optional[list[str]] = None,
+        replica_regions: Optional[list[dict[str, str]]] = None,
         force_overwrite: bool = False,
-    ) -> Tuple[FakeSecret, bool]:
+    ) -> tuple[FakeSecret, bool]:
         if version_stages is None:
             version_stages = ["AWSCURRENT"]
 
@@ -738,10 +736,10 @@ class SecretsManagerBackend(BaseBackend):
         secret_string: Optional[str] = None,
         secret_binary: Optional[str] = None,
         description: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[list[dict[str, str]]] = None,
         kms_key_id: Optional[str] = None,
         version_id: Optional[str] = None,
-        replica_regions: Optional[List[Dict[str, str]]] = None,
+        replica_regions: Optional[list[dict[str, str]]] = None,
         force_overwrite: bool = False,
     ) -> FakeSecret:
         """Create an AWS managed secret for the specified service name."""
@@ -774,7 +772,7 @@ class SecretsManagerBackend(BaseBackend):
         secret_string: str,
         secret_binary: str,
         client_request_token: str,
-        version_stages: List[str],
+        version_stages: list[str],
     ) -> str:
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
@@ -816,7 +814,7 @@ class SecretsManagerBackend(BaseBackend):
         secret_id: str,
         client_request_token: Optional[str] = None,
         rotation_lambda_arn: Optional[str] = None,
-        rotation_rules: Optional[Dict[str, Any]] = None,
+        rotation_rules: Optional[dict[str, Any]] = None,
         rotate_immediately: bool = True,
     ) -> str:
         rotation_days = "AutomaticallyAfterDays"
@@ -909,8 +907,8 @@ class SecretsManagerBackend(BaseBackend):
 
             lambda_backend = get_backend(self.account_id, self.region_name)
 
-            request_headers: Dict[str, Any] = {}
-            response_headers: Dict[str, Any] = {}
+            request_headers: dict[str, Any] = {}
+            response_headers: dict[str, Any] = {}
 
             try:
                 lambda_backend.get_function(secret.rotation_lambda_arn)
@@ -1018,12 +1016,12 @@ class SecretsManagerBackend(BaseBackend):
 
     def list_secrets(
         self,
-        filters: List[Dict[str, Any]],
+        filters: list[dict[str, Any]],
         max_results: int = MAX_RESULTS_DEFAULT,
         next_token: Optional[str] = None,
         include_planned_deletion: bool = False,
-    ) -> Tuple[List[Dict[str, Any]], Optional[str]]:
-        secret_list: List[Dict[str, Any]] = []
+    ) -> tuple[list[dict[str, Any]], Optional[str]]:
+        secret_list: list[dict[str, Any]] = []
         for secret in self.secrets.values():
             if hasattr(secret, "deleted_date"):
                 if secret.deleted_date and not include_planned_deletion:
@@ -1040,7 +1038,7 @@ class SecretsManagerBackend(BaseBackend):
         secret_id: str,
         recovery_window_in_days: Optional[int],
         force_delete_without_recovery: bool,
-    ) -> Tuple[str, str, float]:
+    ) -> tuple[str, str, float]:
         if recovery_window_in_days is not None and (
             recovery_window_in_days < 7 or recovery_window_in_days > 30
         ):
@@ -1096,7 +1094,7 @@ class SecretsManagerBackend(BaseBackend):
 
             return arn, name, self._unix_time_secs(deletion_date)
 
-    def restore_secret(self, secret_id: str) -> Tuple[str, str]:
+    def restore_secret(self, secret_id: str) -> tuple[str, str]:
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
 
@@ -1107,7 +1105,7 @@ class SecretsManagerBackend(BaseBackend):
 
         return secret.arn, secret.name
 
-    def tag_resource(self, secret_id: str, tags: List[Dict[str, str]]) -> None:
+    def tag_resource(self, secret_id: str, tags: list[dict[str, str]]) -> None:
         if secret_id not in self.secrets:
             raise SecretNotFoundException()
 
@@ -1122,7 +1120,7 @@ class SecretsManagerBackend(BaseBackend):
 
         secret.tags = list(old_tags.values())
 
-    def untag_resource(self, secret_id: str, tag_keys: List[str]) -> None:
+    def untag_resource(self, secret_id: str, tag_keys: list[str]) -> None:
         if secret_id not in self.secrets:
             raise SecretNotFoundException()
 
@@ -1141,7 +1139,7 @@ class SecretsManagerBackend(BaseBackend):
         version_stage: str,
         remove_from_version_id: str,
         move_to_version_id: str,
-    ) -> Tuple[str, str]:
+    ) -> tuple[str, str]:
         if secret_id not in self.secrets:
             raise SecretNotFoundException()
 
@@ -1197,7 +1195,7 @@ class SecretsManagerBackend(BaseBackend):
 
         return secret.arn, secret.name
 
-    def put_resource_policy(self, secret_id: str, policy: str) -> Tuple[str, str]:
+    def put_resource_policy(self, secret_id: str, policy: str) -> tuple[str, str]:
         """
         The BlockPublicPolicy-parameter is not yet implemented
         """
@@ -1225,7 +1223,7 @@ class SecretsManagerBackend(BaseBackend):
             resp["ResourcePolicy"] = secret.policy
         return json.dumps(resp)
 
-    def delete_resource_policy(self, secret_id: str) -> Tuple[str, str]:
+    def delete_resource_policy(self, secret_id: str) -> tuple[str, str]:
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
 
@@ -1238,9 +1236,9 @@ class SecretsManagerBackend(BaseBackend):
     def replicate_secret_to_regions(
         self,
         secret_id: str,
-        replica_regions: List[Dict[str, str]],
+        replica_regions: list[dict[str, str]],
         force_overwrite: bool,
-    ) -> Tuple[str, List[Dict[str, Any]]]:
+    ) -> tuple[str, list[dict[str, Any]]]:
         secret = self.describe_secret(secret_id)
         if isinstance(secret, ReplicaSecret):
             raise OperationNotPermittedOnReplica
@@ -1251,8 +1249,8 @@ class SecretsManagerBackend(BaseBackend):
         return secret_id, statuses
 
     def remove_regions_from_replication(
-        self, secret_id: str, replica_regions: List[str]
-    ) -> Tuple[str, List[Dict[str, str]]]:
+        self, secret_id: str, replica_regions: list[str]
+    ) -> tuple[str, list[dict[str, str]]]:
         secret = self.describe_secret(secret_id)
         if isinstance(secret, ReplicaSecret):
             raise OperationNotPermittedOnReplica
@@ -1268,10 +1266,10 @@ class SecretsManagerBackend(BaseBackend):
 
     def _get_secret_values_page_and_next_token(
         self,
-        secret_list: List[Dict[str, Any]],
+        secret_list: list[dict[str, Any]],
         max_results: Optional[int],
         next_token: Optional[str],
-    ) -> Tuple[List[Dict[str, Any]], Optional[str]]:
+    ) -> tuple[list[dict[str, Any]], Optional[str]]:
         starting_point = int(next_token or 0)
         ending_point = starting_point + int(max_results or MAX_RESULTS_DEFAULT)
         secret_page = secret_list[starting_point:ending_point]
