@@ -1,4 +1,4 @@
-from typing import Final, List
+from typing import Final
 
 from moto.stepfunctions.parser.asl.component.common.jsonata.jsonata_template_binding import (
     JSONataTemplateBinding,
@@ -10,12 +10,12 @@ from moto.stepfunctions.parser.asl.eval.environment import Environment
 
 
 class JSONataTemplateValueObject(JSONataTemplateValue):
-    bindings: Final[List[JSONataTemplateBinding]]
+    bindings: Final[list[JSONataTemplateBinding]]
 
-    def __init__(self, bindings: List[JSONataTemplateBinding]):
+    def __init__(self, bindings: list[JSONataTemplateBinding]):
         self.bindings = bindings
 
     def _eval_body(self, env: Environment) -> None:
-        env.stack.append(dict())
+        env.stack.append({})
         for binding in self.bindings:
             binding.eval(env)
